Learn R Programming

RDML (version 0.9-1)

new: Creates new instance of RDML class object

Description

This function has been designed to import data from RDML v1.1 and v1.2 format files

Arguments

filename
string -- path to RDML file
conditions.sep
separator for condition defined at sample name

Warning

Although the format RDML claimed as data exchange format, the specific implementation of the format at devices from real manufacturers differ significantly. Currently this function is checked against RDML data from devices: Bio-Rad CFX96, Roche LightCycler 96 and Applied Biosystems StepOne.

Examples

Run this code
## Not run: 
# ## Import from RDML file
# PATH <- path.package("RDML")
# filename <- paste(PATH, "/extdata/", "lc96_bACTXY.rdml", sep ="")
# lc96 <- RDML$new(filename)
# 
# ## Some kind of overview for lc96
# lc96$AsTable(name.pattern = sample[[react$sample$id]]$description)
# lc96$AsDendrogram()
# ## End(Not run)

Run the code above in your browser using DataLab