Learn R Programming

RDML (version 0.9-1)

thermalCyclingConditionsType: thermalCyclingConditionsType R6 class.

Description

A cycling program for PCR or to amplify cDNA. Inherits: rdmlBaseType.

Usage

thermalCyclingConditionsType

Arguments

Format

An R6Class generator object.

Initialization

thermalCyclingConditionsType$new(id, description = NULL, documentation = NULL, lidTemperature = NULL, experimenter = NULL, step)

Fields

id
idType.
description
is.string.
documentation
list of idReferencesType.
lidTemperature
double. The temperature in degrees Celsius of the lid during cycling.
experimenter
list of idReferencesType. Reference to the person who made or uses this protocol.
step
list of stepType. The steps a protocol runs through to amplify DNA.